@@ -113,14 +113,26 @@ class CObject(object):
     def assign_preferred_name(self, is_embedded=False):
         """This assigns a name to the object if we are nameless and anonymous, safe to call multiple times."""
         self.preferred_name = get_preferred_struct_name(self.names)
+        # Any object that starts with _ won't be imported with import * statement so lets push it to the end
+        if self.preferred_name and self.preferred_name.startswith('_'):
+            modified_name = reverse_leading_underscores(self.preferred_name)
+            self.names.append(modified_name)
+            self.preferred_name = get_preferred_struct_name(self.names)
         if self.is_anonymous and not self.preferred_name:
             self.preferred_name = f"Nameless{get_unique_number()}"
         if self.preferred_name and not is_embedded:
             self.preferred_name = convert_to_snake_case(self.preferred_name)
-        
+
+
+_start_of_obj_blacklist = (
+    re.compile(r'''struct [aA-zZ\\_]+ [aA-zZ\\_]+;'''), # struct some_random_struct_name value;
+)
 
 def is_line_start_of_object(line):
     "Returns True if we are a c object (enum, struct, union)"
+    for regex in _start_of_obj_blacklist:
+        if bool(regex.search(line)):
+            return False
     return bool(re.search('\btypedef struct$|struct$|struct \S*$|enum|union', line))
 
 # This contains all the objects that don't pass convert_to_ctype_object
@@ -227,6 +239,13 @@ def parse_object(f, pos=-1, pack_size=None, is_embedded=False):
             f.seek(pos)
     raise RuntimeError("parse_object(): Failure. This is a bug and we shouldn't be here!")
 
+def reverse_leading_underscores(value: str):
+    """Take a string starting with underscores and moves them to the end. Returns a string"""
+    if value.startswith('_'):
+        underscore_count = len(value) - len(value.lstrip('_'))
+        return value.lstrip('_') + '_'*underscore_count
+    # We didn't have underscores in the value
+    return value
 
 
 def parse_struct_member(buffered_line):
@@ -296,11 +315,13 @@ def parse_struct_member(buffered_line):
 
     # remove stuff that shouldn't be in the name
     data_name = re.sub('{|{|}|\s*', '', data_name)
-    data_type = re.sub('union|{|{|}', '', data_type)
+    data_type = re.sub('union|{|{|}|^struct', '', data_type)
     data_type = data_type.strip()
     if not data_type:
         data_name = ''
-
+    # Any object that starts with _ won't be imported with import * statement so lets push it to the end
+    if data_type.startswith('_') and not convert_to_ctype_object(data_type):
+        data_type = reverse_leading_underscores(data_type)
     return re.sub('\[.*\]|;', '', data_name), data_type, array_length, bitwise_length
 
 
@@ -417,6 +438,7 @@ def convert_to_ctype_object(data_type):
     
     # This is dirty but we don't parse typedefs...
     ctype_types["c_uint16"] = ctype_types["c_uint16"] + ("descIdType",)
+    ctype_types["c_uint64"] = ctype_types["c_uint64"] + ("_clock_identity",)
 
     is_pointer = '*' in data_type and not 'void' in data_type
     for ctype_type, c_types in ctype_types.items():
@@ -542,7 +564,7 @@ def generate(filename='include/ics/icsnVC40.h'):
     except FileNotFoundError:
         pass
     ignore_names = [
-        '__fsid_t', '__darwin_pthread_handler_rec', '_mbstate_t',
+        '__fsid_t', '__darwin_pthread_handler_rec', '_mbstate_t', 'mbstate_t_',
         '_opaque_pthread_attr_t', '_opaque_pthread_cond_t', '_opaque_pthread_condattr_t',
         '_opaque_pthread_mutex_t', '_opaque_pthread_mutexattr_t', '_opaque_pthread_once_t',
         '_opaque_pthread_rwlock_t', '_opaque_pthread_rwlockattr_t', '_opaque_pthread_t',
