@@ -82,7 +82,21 @@ PyObject* meth_disk_format(PyObject* self, PyObject* args);
 PyObject* meth_disk_format_cancel(PyObject* self, PyObject* args);
 PyObject* meth_get_disk_format_progress(PyObject* self, PyObject* args);
 PyObject* meth_enable_doip_line(PyObject* self, PyObject* args); //icsneoEnableDOIPLine
-//PyObject* meth_is_device_feature_supported(PyObject* self, PyObject* args); // icsneoIsDeviceFeatureSupported
+PyObject* meth_is_device_feature_supported(PyObject* self, PyObject* args); // icsneoIsDeviceFeatureSupported
+PyObject* meth_get_pcb_serial_number(PyObject* self, PyObject* args);
+PyObject* meth_set_led_property(PyObject* self, PyObject* args);
+PyObject* meth_start_dhcp_server(PyObject* self, PyObject* args);
+PyObject* meth_stop_dhcp_server(PyObject* self, PyObject* args);
+PyObject* meth_wbms_manager_write_lock(PyObject* self, PyObject* args);
+PyObject* meth_wbms_manager_reset(PyObject* self, PyObject* args);
+PyObject* meth_uart_write(PyObject* self, PyObject* args);
+PyObject* meth_uart_read(PyObject* self, PyObject* args);
+PyObject* meth_uart_set_baudrate(PyObject* self, PyObject* args);
+PyObject* meth_uart_get_baudrate(PyObject* self, PyObject* args);
+PyObject* meth_generic_api_send_command(PyObject* self, PyObject* args);
+PyObject* meth_generic_api_read_data(PyObject* self, PyObject* args);
+PyObject* meth_generic_api_get_status(PyObject* self, PyObject* args);
+
 
 #ifdef _cplusplus
 }
@@ -201,7 +215,7 @@ PyObject* meth_enable_doip_line(PyObject* self, PyObject* args); //icsneoEnableD
     "\n" \
     "Args:\n" \
     "\tdevice (:class:`" MODULE_NAME "." NEO_DEVICE_OBJECT_NAME "`): :class:`" MODULE_NAME "." NEO_DEVICE_OBJECT_NAME "`\n\n" \
-    "\time (:class:`datetime.datetime`): Optional. Sets to current time, if omitted.\n\n" \
+    "\ttime (:class:`datetime.datetime`): Optional. Sets to current time, if omitted.\n\n" \
     "\n" \
     "Raises:\n" \
     "\t:class:`" MODULE_NAME ".RuntimeError`\n" \
@@ -333,7 +347,7 @@ PyObject* meth_enable_doip_line(PyObject* self, PyObject* args); //icsneoEnableD
     "Args:\n" \
     "\tdevice (:class:`" MODULE_NAME "." NEO_DEVICE_OBJECT_NAME "`): :class:`" MODULE_NAME "." NEO_DEVICE_OBJECT_NAME "`\n\n" \
     "\tj1850 (:class:`bool`): Return :class:`" MODULE_NAME "." SPY_MESSAGE_J1850_OBJECT_NAME "` instead.\n\n" \
-    "\timeout (:class:`float`): Optional timeout to wait for messages in seconds (0.1 = 100ms).\n\n" \
+    "\ttimeout (:class:`float`): Optional timeout to wait for messages in seconds (0.1 = 100ms).\n\n" \
     "\n" \
     "Raises:\n" \
     "\t:class:`" MODULE_NAME ".RuntimeError`\n" \
@@ -1391,6 +1405,287 @@ PyObject* meth_enable_doip_line(PyObject* self, PyObject* args); //icsneoEnableD
     "\t>>> supported = ics.is_device_feature_supported(d, DeviceFeature.networkTerminationDWCAN01)\n" \
     "\t>>> \n"
 
+
+#define _DOC_GET_PCB_SERIAL_NUMBER \
+    MODULE_NAME ".get_pcb_serial_number(device)\n" \
+    "\n" \
+    "Gets the unique PCB serial number of the device.\n" \
+    "\n" \
+    "Args:\n" \
+    "\tdevice (:class:`" MODULE_NAME "." NEO_DEVICE_OBJECT_NAME "`): :class:`" MODULE_NAME "." NEO_DEVICE_OBJECT_NAME "`\n\n" \
+    "\n" \
+    "Raises:\n" \
+    "\t:class:`" MODULE_NAME ".RuntimeError`\n" \
+    "\n" \
+    "Returns:\n" \
+    "\t(:class:`str`): PCB Serial Number\n" \
+    "\n" \
+    "\t>>> import ics\n" \
+    "\t>>> d = ics.open_device()\n" \
+    "\t>>> pcb_sn = ics.get_pcb_serial_number(d)\n" \
+    "\t>>> \n"
+
+#define _DOC_SET_LED_PROPERTY \
+    MODULE_NAME ".set_led_property(device, led, prop, value)\n" \
+    "\n" \
+    "Sets the LED property on the device.\n" \
+    "\n" \
+    "Args:\n" \
+    "\tdevice (:class:`" MODULE_NAME "." NEO_DEVICE_OBJECT_NAME "`): :class:`" MODULE_NAME "." NEO_DEVICE_OBJECT_NAME "`\n\n" \
+    "\tled (:class:`int`): Index or position of the LED\n\n" \
+    "\tprop (:class:`int`): Property of the LED\n\n" \
+    "\tvalue (:class:`int`): Value of the LED Property\n\n" \
+    "\n" \
+    "Raises:\n" \
+    "\t:class:`" MODULE_NAME ".RuntimeError`\n" \
+    "\n" \
+    "Returns:\n" \
+    "\tNone.\n" \
+    "\n" \
+    "\t>>> import ics\n" \
+    "\t>>> d = ics.open_device()\n" \
+    "\t>>> ics.set_led_property(d, TODO, TODO, TODO)\n" \
+    "\t>>> \n"
+
+#define _DOC_START_DHCP_SERVER \
+    MODULE_NAME ".start_dhcp_server(device, network_id, device_ip_address, subnet_mask, gateway, start_address, end_address, overwrite_dhcp_settings, lease_time, reserved)\n" \
+    "\n" \
+    "Starts a DHCP Server.\n" \
+    "\n" \
+    "Args:\n" \
+    "\tdevice (:class:`" MODULE_NAME "." NEO_DEVICE_OBJECT_NAME "`): :class:`" MODULE_NAME "." NEO_DEVICE_OBJECT_NAME "`\n\n" \
+    "\tnetwork_id (:class:`int`): NetworkID\n\n" \
+    "\tdevice_ip_address (:class:`str`): Device IP Address\n\n" \
+    "\tsubnet_mask (:class:`str`): Subnet Mask\n\n" \
+    "\tgateway (:class:`str`): Gateway\n\n" \
+    "\tstart_address (:class:`str`): Start Address\n\n" \
+    "\tend_address (:class:`str`): End Address\n\n" \
+    "\toverwrite_dhcp_settings (:class:`bool`): Overwrite DHCP Settings\n\n" \
+    "\tlease_time (:class:`int`): Lease time\n\n" \
+    "\treserved (:class:`int`): (Optional) Reserved, set to 0\n\n" \
+    "\n" \
+    "Raises:\n" \
+    "\t:class:`" MODULE_NAME ".RuntimeError`\n" \
+    "\n" \
+    "Returns:\n" \
+    "\tNone.\n" \
+    "\n" \
+    "\t>>> import ics\n" \
+    "\t>>> d = ics.open_device()\n" \
+    "\t>>> ics.start_dhcp_server(d, TODO)\n" \
+    "\t>>> \n"
+
+#define _DOC_STOP_DHCP_SERVER \
+    MODULE_NAME ".stop_dhcp_server(device, network_id)\n" \
+    "\n" \
+    "Stops the DHCP Server\n" \
+    "\n" \
+    "Args:\n" \
+    "\tdevice (:class:`" MODULE_NAME "." NEO_DEVICE_OBJECT_NAME "`): :class:`" MODULE_NAME "." NEO_DEVICE_OBJECT_NAME "`\n\n" \
+    "\tnetwork_id (:class:`int`): NetworkID\n\n" \
+    "\n" \
+    "Raises:\n" \
+    "\t:class:`" MODULE_NAME ".RuntimeError`\n" \
+    "\n" \
+    "Returns:\n" \
+    "\tNone.\n" \
+    "\n" \
+    "\t>>> import ics\n" \
+    "\t>>> d = ics.open_device()\n" \
+    "\t>>> ics.stop_dhcp_server(d, TODO)\n" \
+    "\t>>> \n"
+
+#define _DOC_WBMS_MANAGER_WRITE_LOCK \
+    MODULE_NAME ".wbms_manager_write_lock(device, manager, lock_state)\n" \
+    "\n" \
+    "Sets the lock state on the manager\n" \
+    "\n" \
+    "Args:\n" \
+    "\tdevice (:class:`" MODULE_NAME "." NEO_DEVICE_OBJECT_NAME "`): :class:`" MODULE_NAME "." NEO_DEVICE_OBJECT_NAME "`\n\n" \
+    "\tmanager (:class:`" MODULE_NAME ".structures.ew_bms_manager_port_t.ew_bms_manager_port_t`): :class:`" MODULE_NAME ".structures.ew_bms_manager_port_t.ew_bms_manager_port_t`\n\n" \
+    "\tlock_state (:class:`" MODULE_NAME ".structures.ew_bms_manager_lock_state_t.ew_bms_manager_lock_state_t`): :class:`" MODULE_NAME ".structures.ew_bms_manager_lock_state_t.ew_bms_manager_lock_state_t`\n\n" \
+    "\n" \
+    "Raises:\n" \
+    "\t:class:`" MODULE_NAME ".RuntimeError`\n" \
+    "\n" \
+    "Returns:\n" \
+    "\tNone.\n" \
+    "\n" \
+    "\t>>> import ics\n" \
+    "\t>>> from ics.structures.ew_bms_manager_port_t import ew_bms_manager_port_t\n" \
+    "\t>>> from ics.structures.ew_bms_manager_lock_state_t import ew_bms_manager_lock_state_t\n" \
+    "\t>>> d = ics.open_device()\n" \
+    "\t>>> ics.wbms_manager_write_lock(d, ew_bms_manager_port_t.eManagerPortA.value, ew_bms_manager_lock_state_t.eLockManager.value)\n" \
+    "\t>>> \n"
+
+#define _DOC_WBMS_MANAGER_RESET \
+    MODULE_NAME ".wbms_manager_reset(device, manager)\n" \
+    "\n" \
+    "Resets the manager\n" \
+    "\n" \
+    "Args:\n" \
+    "\tdevice (:class:`" MODULE_NAME "." NEO_DEVICE_OBJECT_NAME "`): :class:`" MODULE_NAME "." NEO_DEVICE_OBJECT_NAME "`\n\n" \
+    "\tmanager (:class:`" MODULE_NAME ".structures.ew_bms_manager_port_t.ew_bms_manager_port_t`): :class:`" MODULE_NAME ".structures.ew_bms_manager_port_t.ew_bms_manager_port_t`\n\n" \
+    "\n" \
+    "Raises:\n" \
+    "\t:class:`" MODULE_NAME ".RuntimeError`\n" \
+    "\n" \
+    "Returns:\n" \
+    "\tNone.\n" \
+    "\n" \
+    "\t>>> import ics\n" \
+    "\t>>> from ics.structures.ew_bms_manager_port_t import ew_bms_manager_port_t\n" \
+    "\t>>> d = ics.open_device()\n" \
+    "\t>>> ics.wbms_manager_reset(d, ew_bms_manager_port_t.eManagerPortA.value)\n" \
+    "\t>>> \n"    
+
+#define _DOC_UART_WRITE \
+    MODULE_NAME ".uart_write(device, port, data, flags)\n" \
+    "\n" \
+    "Writes UART on the given port\n" \
+    "\n" \
+    "Args:\n" \
+    "\tdevice (:class:`" MODULE_NAME "." NEO_DEVICE_OBJECT_NAME "`): :class:`" MODULE_NAME "." NEO_DEVICE_OBJECT_NAME "`\n\n" \
+    "\tport (:class:`" MODULE_NAME ".structures.e_uart_port_t.e_uart_port_t`): :class:`" MODULE_NAME ".structures.e_uart_port_t.e_uart_port_t`\n\n" \
+    "\tdata (:class:`bytes): :class:`bytes\n\n" \
+    "\n" \
+    "Raises:\n" \
+    "\t:class:`" MODULE_NAME ".RuntimeError`\n" \
+    "\n" \
+    "Returns:\n" \
+    "\tNone.\n" \
+    "\n" \
+    "\t>>> import ics\n" \
+    "\t>>> from ics.structures.e_uart_port_t import e_uart_port_t\n" \
+    "\t>>> d = ics.open_device()\n" \
+    "\t>>> ics.uart_write(d, e_uart_port_t.eUART0, b'my uart data goes here')\n" \
+    "\t>>> \n"
+
+#define _DOC_UART_READ \
+    MODULE_NAME ".uart_read(device, port, bytes_to_read, flags)\n" \
+    "\n" \
+    "Reads UART on the given port. \n" \
+    "\n" \
+    "Args:\n" \
+    "\tdevice (:class:`" MODULE_NAME "." NEO_DEVICE_OBJECT_NAME "`): :class:`" MODULE_NAME "." NEO_DEVICE_OBJECT_NAME "`\n\n" \
+    "\tport (:class:`" MODULE_NAME ".structures.e_uart_port_t.e_uart_port_t`): :class:`" MODULE_NAME ".structures.e_uart_port_t.e_uart_port_t`\n\n" \
+    "\tbytes_to_read (:class:`int`): Optional. How many bytes to read from the UART, 256 if omitted.\n\n" \
+    "\tflags (:class:`int`): Optional. Flags to be used. Don't use if unsure.\n\n" \
+    "\n" \
+    "Raises:\n" \
+    "\t:class:`" MODULE_NAME ".RuntimeError`\n" \
+    "\n" \
+    "Returns:\n" \
+    "\tNone.\n" \
+    "\n" \
+    "\t>>> import ics\n" \
+    "\t>>> from ics.structures.e_uart_port_t import e_uart_port_t\n" \
+    "\t>>> d = ics.open_device()\n" \
+    "\t>>> data = ics.uart_read(d, e_uart_port_t.eUART0)\n" \
+    "\t>>> print(f\"Read {len(data)} bytes: {data}\")\n" \
+    "\t>>> \n"
+
+#define _DOC_UART_SET_BAUDRATE \
+    MODULE_NAME ".uart_set_baudrate(device, port, baudrate)\n" \
+    "\n" \
+    "Sets the UART baudrate on the given port. \n" \
+    "\n" \
+    "Args:\n" \
+    "\tdevice (:class:`" MODULE_NAME "." NEO_DEVICE_OBJECT_NAME "`): :class:`" MODULE_NAME "." NEO_DEVICE_OBJECT_NAME "`\n\n" \
+    "\tport (:class:`" MODULE_NAME ".structures.e_uart_port_t.e_uart_port_t`): :class:`" MODULE_NAME ".structures.e_uart_port_t.e_uart_port_t`\n\n" \
+    "\tbaudrate (:class:`int`): Baudrate of the UART to set.\n\n" \
+    "\n" \
+    "Raises:\n" \
+    "\t:class:`" MODULE_NAME ".RuntimeError`\n" \
+    "\n" \
+    "Returns:\n" \
+    "\tNone.\n" \
+    "\n" \
+    "\t>>> import ics\n" \
+    "\t>>> from ics.structures.e_uart_port_t import e_uart_port_t\n" \
+    "\t>>> d = ics.open_device()\n" \
+    "\t>>> ics.uart_set_baudrate(d, e_uart_port_t.eUART0, 115200)\n" \
+    "\t>>> print(f\"Read {len(data)} bytes: {data}\")\n" \
+    "\t>>> \n"
+
+#define _DOC_UART_GET_BAUDRATE \
+    MODULE_NAME ".uart_get_baudrate(device, port)\n" \
+    "\n" \
+    "Gets the UART baudrate on the given port. \n" \
+    "\n" \
+    "Args:\n" \
+    "\tdevice (:class:`" MODULE_NAME "." NEO_DEVICE_OBJECT_NAME "`): :class:`" MODULE_NAME "." NEO_DEVICE_OBJECT_NAME "`\n\n" \
+    "\tport (:class:`" MODULE_NAME ".structures.e_uart_port_t.e_uart_port_t`): :class:`" MODULE_NAME ".structures.e_uart_port_t.e_uart_port_t`\n\n" \
+    "\n" \
+    "Raises:\n" \
+    "\t:class:`" MODULE_NAME ".RuntimeError`\n" \
+    "\n" \
+    "Returns:\n" \
+    "\tNone.\n" \
+    "\n" \
+    "\t>>> import ics\n" \
+    "\t>>> from ics.structures.e_uart_port_t import e_uart_port_t\n" \
+    "\t>>> d = ics.open_device()\n" \
+    "\t>>> baudrate = ics.uart_set_baudrate(d, e_uart_port_t.eUART0)\n" \
+    "\t>>> \n"
+
+#define _DOC_GENERIC_API_SEND_COMMAND \
+    MODULE_NAME ".generic_api_send_command(device, api_index, instance_index, function_index, data)\n" \
+    "\n" \
+    "Sends a command in a generic way.\n" \
+    "\n" \
+    "Args:\n" \
+    "\tdevice (:class:`" MODULE_NAME "." NEO_DEVICE_OBJECT_NAME "`): :class:`" MODULE_NAME "." NEO_DEVICE_OBJECT_NAME "`\n\n" \
+    "\tapi_index (:class:`int`): api_index.\n\n" \
+    "\tinstance_index (:class:`int`): instance_index.\n\n" \
+    "\tfunction_index (:class:`int`): function_index.\n\n" \
+    "\tdata (:class:`bytes`): Data to be passed in.\n\n" \
+    "\n" \
+    "Raises:\n" \
+    "\t:class:`" MODULE_NAME ".RuntimeError`\n" \
+    "\n" \
+    "Returns:\n" \
+    "\tfunctionError (:class:`int`): functionError.\n\n" \
+    "\n"
+
+// if (!PyArg_ParseTuple(args, arg_parse("ObbI:", __FUNCTION__), &obj, &apiIndex, &instanceIndex, &length)) {
+#define _DOC_GENERIC_API_READ_DATA \
+    MODULE_NAME ".generic_api_read_data(device, api_index, instance_index, [length])\n" \
+    "\n" \
+    "Reads data in a generic way.\n" \
+    "\n" \
+    "Args:\n" \
+    "\tdevice (:class:`" MODULE_NAME "." NEO_DEVICE_OBJECT_NAME "`): :class:`" MODULE_NAME "." NEO_DEVICE_OBJECT_NAME "`\n\n" \
+    "\tapi_index (:class:`int`): api_index.\n\n" \
+    "\tinstance_index (:class:`int`): instance_index.\n\n" \
+    "\tfunction_index (:class:`int`): function_index.\n\n" \
+    "\tlength (:class:`int`): (optional) Length of the data to read. defaults to `GENERIC_API_DATA_BUFFER_SIZE`\n\n" \
+    "\n" \
+    "Raises:\n" \
+    "\t:class:`" MODULE_NAME ".RuntimeError`\n" \
+    "\n" \
+    "Returns:\n" \
+    "\ttuple of (functionError, data) \n\n" \
+    "\n"
+
+// if (!PyArg_ParseTuple(args, arg_parse("Obb:", __FUNCTION__), &obj, &apiIndex, &instanceIndex)) {
+#define _DOC_GENERIC_API_GET_STATUS \
+    MODULE_NAME ".generic_api_get_status(device, api_index, instance_index)\n" \
+    "\n" \
+    "Reads data in a generic way.\n" \
+    "\n" \
+    "Args:\n" \
+    "\tdevice (:class:`" MODULE_NAME "." NEO_DEVICE_OBJECT_NAME "`): :class:`" MODULE_NAME "." NEO_DEVICE_OBJECT_NAME "`\n\n" \
+    "\tapi_index (:class:`int`): api_index.\n\n" \
+    "\tinstance_index (:class:`int`): instance_index.\n\n" \
+    "\n" \
+    "Raises:\n" \
+    "\t:class:`" MODULE_NAME ".RuntimeError`\n" \
+    "\n" \
+    "Returns:\n" \
+    "\ttuple of (:class:`int`): (functionIndex, callbackError, finishedProcessing) \n\n" \
+    "\n"
+
 static PyMethodDef IcsMethods[] = {
     _EZ_ICS_STRUCT_METHOD("find_devices", "icsneoFindNeoDevices", "FindNeoDevices", (PyCFunction)meth_find_devices, METH_VARARGS | METH_KEYWORDS, _DOC_FIND_DEVICES),
     _EZ_ICS_STRUCT_METHOD("open_device", "icsneoOpenNeoDevice", "OpenNeoDevice", (PyCFunction)meth_open_device, METH_VARARGS | METH_KEYWORDS, _DOC_OPEN_DEVICES),
@@ -1470,8 +1765,21 @@ static PyMethodDef IcsMethods[] = {
     _EZ_ICS_STRUCT_METHOD("disk_format_cancel", "icsneoRequestDiskFormatCancel", "RequestDiskFormatCancel", meth_disk_format_cancel, METH_VARARGS, _DOC_DISK_FORMAT_CANCEL),
     _EZ_ICS_STRUCT_METHOD("get_disk_format_progress", "icsneoRequestDiskFormatProgress", "RequestDiskFormatProgress", meth_get_disk_format_progress, METH_VARARGS, _DOC_DISK_FORMAT_PROGRESS),
     _EZ_ICS_STRUCT_METHOD("enable_doip_line", "icsneoEnableDOIPLine", "EnableDOIPLine", meth_enable_doip_line, METH_VARARGS, _DOC_ENABLE_DOIP_LINE),
-    // not in official builds yet...
-    //_EZ_ICS_STRUCT_METHOD("is_device_feature_supported", "icsneoIsDeviceFeatureSupported", "IsDeviceFeatureSupported", meth_is_device_feature_supported, METH_VARARGS, _DOC_IS_DEVICE_FEATURE_SUPPORTED),
+    _EZ_ICS_STRUCT_METHOD("is_device_feature_supported", "icsneoIsDeviceFeatureSupported", "IsDeviceFeatureSupported", meth_is_device_feature_supported, METH_VARARGS, _DOC_IS_DEVICE_FEATURE_SUPPORTED),
+    _EZ_ICS_STRUCT_METHOD("get_pcb_serial_number", "icsneoGetPCBSerialNumber", "GetPCBSerialNumber", meth_get_pcb_serial_number, METH_VARARGS, _DOC_GET_PCB_SERIAL_NUMBER),
+    _EZ_ICS_STRUCT_METHOD("set_led_property", "icsneoSetLedProperty", "SetLedProperty", meth_set_led_property, METH_VARARGS, _DOC_SET_LED_PROPERTY),
+    _EZ_ICS_STRUCT_METHOD("start_dhcp_server", "icsneoStartDHCPServer", "StartDHCPServer", meth_start_dhcp_server, METH_VARARGS, _DOC_START_DHCP_SERVER),
+    _EZ_ICS_STRUCT_METHOD("stop_dhcp_server", "icsneoStopDHCPServer", "StopDHCPServer", meth_stop_dhcp_server, METH_VARARGS, _DOC_STOP_DHCP_SERVER),
+
+    _EZ_ICS_STRUCT_METHOD("wbms_manager_write_lock", "icsneowBMSManagerWriteLock", "wBMSManagerWriteLock", meth_wbms_manager_write_lock, METH_VARARGS, _DOC_WBMS_MANAGER_WRITE_LOCK),
+    _EZ_ICS_STRUCT_METHOD("wbms_manager_reset", "icsneowBMSManagerReset", "wBMSManagerReset", meth_wbms_manager_reset, METH_VARARGS, _DOC_WBMS_MANAGER_RESET),
+    _EZ_ICS_STRUCT_METHOD("uart_write", "icsneoUartWrite", "UartWrite", meth_uart_write, METH_VARARGS, _DOC_UART_WRITE),
+    _EZ_ICS_STRUCT_METHOD("uart_read", "icsneoUartRead", "UartRead", meth_uart_read, METH_VARARGS, _DOC_UART_READ),
+    _EZ_ICS_STRUCT_METHOD("uart_set_baudrate", "icsneoUartSetBaudrate", "UartSetBaudrate", meth_uart_set_baudrate, METH_VARARGS, _DOC_UART_SET_BAUDRATE),
+    _EZ_ICS_STRUCT_METHOD("uart_get_baudrate", "icsneoUartGetBaudrate", "UartGetBaudrate", meth_uart_get_baudrate, METH_VARARGS, _DOC_UART_GET_BAUDRATE),
+    _EZ_ICS_STRUCT_METHOD("generic_api_send_command", "icsneoGenericAPISendCommand", "GenericAPISendCommand", meth_generic_api_send_command, METH_VARARGS, _DOC_GENERIC_API_SEND_COMMAND),   
+    _EZ_ICS_STRUCT_METHOD("generic_api_read_data", "icsneoGenericAPIReadData", "GenericAPIReadData", meth_generic_api_read_data, METH_VARARGS, _DOC_GENERIC_API_READ_DATA),   
+    _EZ_ICS_STRUCT_METHOD("generic_api_get_status", "icsneoGenericAPIGetStatus", "GenericAPIGetStatus", meth_generic_api_get_status, METH_VARARGS, _DOC_GENERIC_API_GET_STATUS),   
 
     {"override_library_name", (PyCFunction)meth_override_library_name, METH_VARARGS, _DOC_OVERRIDE_LIBRARY_NAME},
     {"get_library_path", (PyCFunction)meth_get_library_path, METH_NOARGS, ""},
