@@ -108,6 +108,7 @@ int setup_module_auto_defines(PyObject * module)
 	result += PyModule_AddIntMacro(module, NETID_ETHERNET3);
 	result += PyModule_AddIntMacro(module, NETID_ISM_LOGGER);
 	result += PyModule_AddIntMacro(module, NETID_CAN_SWITCH);
+	result += PyModule_AddIntMacro(module, NETID_WBMS);
 	result += PyModule_AddIntMacro(module, NETID_MAX);
 	result += PyModule_AddIntMacro(module, NETID_INVALID);
 	result += PyModule_AddIntMacro(module, NEODEVICE_UNKNOWN);
@@ -144,6 +145,7 @@ int setup_module_auto_defines(PyObject * module)
 	result += PyModule_AddIntMacro(module, NEODEVICE_NEW_DEVICE_58);
 	result += PyModule_AddIntMacro(module, NEODEVICE_NEW_DEVICE_59);
 	result += PyModule_AddIntMacro(module, NEODEVICE_RAD_BMS);
+	result += PyModule_AddIntMacro(module, NEODEVICE_RADMOON3);
 	result += PyModule_AddIntMacro(module, NEODEVICE_RED);
 	result += PyModule_AddIntMacro(module, NEODEVICE_ECU);
 	result += PyModule_AddIntMacro(module, NEODEVICE_IEVB);
@@ -173,6 +175,7 @@ int setup_module_auto_defines(PyObject * module)
 	result += PyModule_AddIntMacro(module, NEODEVICE_ANY_PLASMA);
 	result += PyModule_AddIntMacro(module, NEODEVICE_ANY_ION);
 	result += PyModule_AddIntMacro(module, NEODEVICE_NEOECUCHIP);
+	result += PyModule_AddIntMacro(module, DEVICECOUNT_FOR_EXPLORER);
 	result += PyModule_AddIntMacro(module, ISO15765_2_NETWORK_HSCAN);
 	result += PyModule_AddIntMacro(module, ISO15765_2_NETWORK_MSCAN);
 	result += PyModule_AddIntMacro(module, ISO15765_2_NETWORK_HSCAN2);
@@ -232,6 +235,7 @@ int setup_module_auto_defines(PyObject * module)
 	result += PyModule_AddIntMacro(module, SPY_PROTOCOL_UDP);
 	result += PyModule_AddIntMacro(module, SPY_PROTOCOL_AUTOSAR);
 	result += PyModule_AddIntMacro(module, SPY_PROTOCOL_A2B);
+	result += PyModule_AddIntMacro(module, SPY_PROTOCOL_WBMS);
 	result += PyModule_AddIntMacro(module, SPY_STATUS_GLOBAL_ERR);
 	result += PyModule_AddIntMacro(module, SPY_STATUS_TX_MSG);
 	result += PyModule_AddIntMacro(module, SPY_STATUS_XTD_FRAME);
@@ -328,6 +332,8 @@ int setup_module_auto_defines(PyObject * module)
 	result += PyModule_AddIntMacro(module, SPY_STATUS2_FLEXRAY_NO_HEADERCRC);
 	result += PyModule_AddIntMacro(module, SPY_STATUS2_CAN_ISO15765_LOGICAL_FRAME);
 	result += PyModule_AddIntMacro(module, SPY_STATUS2_CAN_HAVE_LINK_DATA);
+	result += PyModule_AddIntMacro(module, SPY_STATUS2_WBMS_NODE_DISCONNECTED);
+	result += PyModule_AddIntMacro(module, SPY_STATUS2_I2C_NODE_FAULT);
 	result += PyModule_AddIntMacro(module, SPY_STATUS3_CANFD_ESI);
 	result += PyModule_AddIntMacro(module, SPY_STATUS3_CANFD_IDE);
 	result += PyModule_AddIntMacro(module, SPY_STATUS3_CANFD_RTR);
@@ -545,6 +551,7 @@ int setup_module_auto_defines(PyObject * module)
 	result += PyModule_AddIntMacro(module, EXTENDED_RESPONSE_INVALID_PARAMETER);
 	// end of enum -  } ExtendedResponseCode;
 
+	result += PyModule_AddIntMacro(module, GENERIC_API_DATA_BUFFER_SIZE);
 	result += PyModule_AddIntMacro(module, GET_SUPPORTED_FEATURES_COMMAND_VERSION);
 	result += PyModule_AddIntMacro(module, MAX_REPORTED_VERSIONS);
 	// enum
@@ -832,6 +839,12 @@ int setup_module_auto_defines(PyObject * module)
 	result += PyModule_AddIntMacro(module, JUPITER_PTP_ROLE_MASTER);
 	result += PyModule_AddIntMacro(module, JUPITER_PTP_ROLE_SLAVE);
 	result += PyModule_AddIntMacro(module, SRADJupiterSettings_SIZE);
+	result += PyModule_AddIntMacro(module, LINUX_BOOT_ALLOWED);
+	result += PyModule_AddIntMacro(module, WIFI_ANTENNA_INTERNAL);
+	result += PyModule_AddIntMacro(module, WIFI_ANTENNA_EXTERNAL);
+	result += PyModule_AddIntMacro(module, LINUX_CONFIG_PORT_NONE);
+	result += PyModule_AddIntMacro(module, LINUX_CONFIG_PORT_ETH_01);
+	result += PyModule_AddIntMacro(module, LINUX_CONFIG_PORT_ETH_02);
 	result += PyModule_AddIntMacro(module, SFire3Settings_SIZE);
 	result += PyModule_AddIntMacro(module, RadMoonDuoSettings_SIZE);
 	result += PyModule_AddIntMacro(module, SEtherBadgeSettings_SIZE);
@@ -889,6 +902,31 @@ int setup_module_auto_defines(PyObject * module)
 	result += PyModule_AddIntMacro(module, eFpgaStatusResp);
 	// end of enum -  } EPlasmaIonVnetChannel_t;
 
+	// enum
+	result += PyModule_AddIntMacro(module, eManagerPortA);
+	result += PyModule_AddIntMacro(module, eManagerPortB);
+	// end of enum -  } EwBMSManagerPort_t;
+
+	// enum
+	result += PyModule_AddIntMacro(module, eLockManager);
+	result += PyModule_AddIntMacro(module, eUnlockManager);
+	// end of enum -  } EwBMSManagerLockState_t;
+
+	// enum
+	result += PyModule_AddIntMacro(module, eUART0);
+	result += PyModule_AddIntMacro(module, eUART1);
+	// end of enum -  } EUartPort_t;
+
+	// enum
+	result += PyModule_AddIntMacro(module, eGENERIC_API);
+	result += PyModule_AddIntMacro(module, eADI_WIL_API);
+	// end of enum -  } eGenericAPIOptions;
+
+	// enum
+	result += PyModule_AddIntMacro(module, ewBMSInstance0);
+	result += PyModule_AddIntMacro(module, ewBMSInstance1);
+	// end of enum -  } EwBMSInstance_t;
+
 	result += PyModule_AddIntMacro(module, stCM_ISO157652_TxMessage_SIZE);
 	result += PyModule_AddIntMacro(module, ISO15765_2015_TxMessage_SIZE);
 	result += PyModule_AddIntMacro(module, stCM_ISO157652_RxMessage_SIZE);
@@ -921,6 +959,28 @@ int setup_module_auto_defines(PyObject * module)
 	result += PyModule_AddIntMacro(module, PHYREG_BOTH);
 	// end of enum -  } PhyRegPktRw_t;
 
+	// enum
+	result += PyModule_AddIntMacro(module, networkDWCAN01);
+	result += PyModule_AddIntMacro(module, networkDWCAN02);
+	result += PyModule_AddIntMacro(module, networkDWCAN03);
+	result += PyModule_AddIntMacro(module, networkDWCAN04);
+	result += PyModule_AddIntMacro(module, networkDWCAN05);
+	result += PyModule_AddIntMacro(module, networkDWCAN06);
+	result += PyModule_AddIntMacro(module, networkDWCAN07);
+	result += PyModule_AddIntMacro(module, networkDWCAN08);
+	result += PyModule_AddIntMacro(module, networkTerminationDWCAN01);
+	result += PyModule_AddIntMacro(module, networkTerminationDWCAN02);
+	result += PyModule_AddIntMacro(module, networkTerminationDWCAN03);
+	result += PyModule_AddIntMacro(module, networkTerminationDWCAN04);
+	result += PyModule_AddIntMacro(module, networkTerminationDWCAN05);
+	result += PyModule_AddIntMacro(module, networkTerminationDWCAN06);
+	result += PyModule_AddIntMacro(module, networkTerminationDWCAN07);
+	result += PyModule_AddIntMacro(module, networkTerminationDWCAN08);
+	result += PyModule_AddIntMacro(module, NUM_VALID_DEVICE_FEATURES);
+	result += PyModule_AddIntMacro(module, supportedFeatureMax);
+	// end of enum -  } DeviceFeature;
+
+	result += PyModule_AddIntMacro(module, NUM_DEVICE_FEATURE_BITFIELDS);
 	// enum
 	// end of enum -    }
 
